@rem
@rem Copyright 2015 the original author or authors.
@rem
@rem Licensed under the Apache License, Version 2.0 (the "License");
@rem you may not use this file except in compliance with the License.
@rem You may obtain a copy of the License at
@rem
@rem      https://www.apache.org/licenses/LICENSE-2.0
@rem
@rem Unless required by applicable law or agreed to in writing, software
@rem distributed under the License is distributed on an "AS IS" BASIS,
@rem WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
@rem See the License for the specific language governing permissions and
@rem limitations under the License.
@rem
@rem SPDX-License-Identifier: Apache-2.0
@rem

@if "%DEBUG%"=="" @echo off
@rem ##########################################################################
@rem
@rem  serving startup script for Windows
@rem
@rem ##########################################################################

@rem Set local scope for the variables with windows NT shell
if "%OS%"=="Windows_NT" setlocal

set DIRNAME=%~dp0
if "%DIRNAME%"=="" set DIRNAME=.
@rem This is normally unused
set APP_BASE_NAME=%~n0
set APP_HOME=%DIRNAME%..

@rem Resolve any "." and ".." in APP_HOME to make it shorter.
for %%i in ("%APP_HOME%") do set APP_HOME=%%~fi

@rem Add default JVM options here. You can also use JAVA_OPTS and SERVING_OPTS to pass JVM options to this script.
set DEFAULT_JVM_OPTS=

@rem Find java.exe
if defined JAVA_HOME goto findJavaFromJavaHome

set JAVA_EXE=java.exe
%JAVA_EXE% -version >NUL 2>&1
if %ERRORLEVEL% equ 0 goto execute

echo. 1>&2
echo ERROR: JAVA_HOME is not set and no 'java' command could be found in your PATH. 1>&2
echo. 1>&2
echo Please set the JAVA_HOME variable in your environment to match the 1>&2
echo location of your Java installation. 1>&2

goto fail

:findJavaFromJavaHome
set JAVA_HOME=%JAVA_HOME:"=%
set JAVA_EXE=%JAVA_HOME%/bin/java.exe

if exist "%JAVA_EXE%" goto execute

echo. 1>&2
echo ERROR: JAVA_HOME is set to an invalid directory: %JAVA_HOME% 1>&2
echo. 1>&2
echo Please set the JAVA_HOME variable in your environment to match the 1>&2
echo location of your Java installation. 1>&2

goto fail

:execute
@rem Setup the command line

set CLASSPATH=%APP_HOME%\lib\serving-0.36.0.jar;%APP_HOME%\lib\wlm-0.36.0.jar;%APP_HOME%\lib\prometheus-0.36.0.jar;%APP_HOME%\lib\python-0.36.0.jar;%APP_HOME%\lib\netty-codec-http-4.1.119.Final.jar;%APP_HOME%\lib\netty-transport-native-epoll-4.1.119.Final-linux-aarch_64.jar;%APP_HOME%\lib\netty-transport-native-epoll-4.1.119.Final-linux-x86_64.jar;%APP_HOME%\lib\netty-transport-native-kqueue-4.1.119.Final-osx-aarch_64.jar;%APP_HOME%\lib\netty-transport-native-kqueue-4.1.119.Final-osx-x86_64.jar;%APP_HOME%\lib\commons-cli-1.9.0.jar;%APP_HOME%\lib\log4j-slf4j2-impl-2.24.3.jar;%APP_HOME%\lib\disruptor-3.4.4.jar;%APP_HOME%\lib\model-zoo-0.36.0.jar;%APP_HOME%\lib\tensorflow-model-zoo-0.36.0.jar;%APP_HOME%\lib\pytorch-model-zoo-0.36.0.jar;%APP_HOME%\lib\tokenizers-0.36.0.jar;%APP_HOME%\lib\xgboost-0.36.0.jar;%APP_HOME%\lib\pytorch-engine-0.36.0.jar;%APP_HOME%\lib\tensorflow-engine-0.36.0.jar;%APP_HOME%\lib\api-0.36.0.jar;%APP_HOME%\lib\tensorflow-api-0.36.0.jar;%APP_HOME%\lib\slf4j-api-2.0.17.jar;%APP_HOME%\lib\snakeyaml-2.4.jar;%APP_HOME%\lib\netty-handler-4.1.119.Final.jar;%APP_HOME%\lib\netty-codec-4.1.119.Final.jar;%APP_HOME%\lib\netty-transport-classes-epoll-4.1.119.Final.jar;%APP_HOME%\lib\netty-transport-classes-kqueue-4.1.119.Final.jar;%APP_HOME%\lib\netty-transport-native-unix-common-4.1.119.Final.jar;%APP_HOME%\lib\netty-transport-4.1.119.Final.jar;%APP_HOME%\lib\netty-buffer-4.1.119.Final.jar;%APP_HOME%\lib\netty-resolver-4.1.119.Final.jar;%APP_HOME%\lib\netty-common-4.1.119.Final.jar;%APP_HOME%\lib\prometheus-metrics-core-1.3.6.jar;%APP_HOME%\lib\prometheus-metrics-exposition-formats-1.3.6.jar;%APP_HOME%\lib\log4j-core-2.24.3.jar;%APP_HOME%\lib\log4j-api-2.24.3.jar;%APP_HOME%\lib\commons-logging-1.3.5.jar;%APP_HOME%\lib\gson-2.13.1.jar;%APP_HOME%\lib\jna-5.17.0.jar;%APP_HOME%\lib\commons-compress-1.27.1.jar;%APP_HOME%\lib\prometheus-metrics-exposition-textformats-1.3.6.jar;%APP_HOME%\lib\prometheus-metrics-model-1.3.6.jar;%APP_HOME%\lib\prometheus-metrics-config-1.3.6.jar;%APP_HOME%\lib\prometheus-metrics-tracer-initializer-1.3.6.jar;%APP_HOME%\lib\error_prone_annotations-2.38.0.jar;%APP_HOME%\lib\commons-codec-1.17.1.jar;%APP_HOME%\lib\commons-io-2.16.1.jar;%APP_HOME%\lib\prometheus-metrics-tracer-otel-1.3.6.jar;%APP_HOME%\lib\prometheus-metrics-tracer-otel-agent-1.3.6.jar;%APP_HOME%\lib\prometheus-metrics-tracer-common-1.3.6.jar;%APP_HOME%\lib\javacpp-1.5.11.jar;%APP_HOME%\lib\protobuf-java-4.31.1.jar


@rem Execute serving
"%JAVA_EXE%" %DEFAULT_JVM_OPTS% %JAVA_OPTS% %SERVING_OPTS%  -classpath "%CLASSPATH%" ai.djl.serving.ModelServer %*

:end
@rem End local scope for the variables with windows NT shell
if %ERRORLEVEL% equ 0 goto mainEnd

:fail
rem Set variable SERVING_EXIT_CONSOLE if you need the _script_ return code instead of
rem the _cmd.exe /c_ return code!
set EXIT_CODE=%ERRORLEVEL%
if %EXIT_CODE% equ 0 set EXIT_CODE=1
if not ""=="%SERVING_EXIT_CONSOLE%" exit %EXIT_CODE%
exit /b %EXIT_CODE%

:mainEnd
if "%OS%"=="Windows_NT" endlocal

:omega
